#! /usr/bin/env python
import os

def rewrite_species_result(input_species_file, output_species_file):
	try:
		with open(input_species_file) as f:
			content = f.read().splitlines()
		f.close()

		largestSpecies = 0
		taxaList = []
		assignments = {}

		for i in range(1,151):
			line = content[i]
			line = " ".join(line.split())
			species_idx = int(line.split(' ')[1])
			taxon_name = line.split(' ')[2]
			if (species_idx > largestSpecies):
				assignments[species_idx] = []
				largestSpecies = species_idx
			assignments[species_idx].append(taxon_name)

		if not os.path.exists(os.path.dirname(output_species_file)):
    			os.makedirs(os.path.dirname(output_species_file))
		speciesOut = open(output_species_file, 'w')

		speciesOut.write("Species 1:\n")
		for j in range(0, len(assignments[1])):
				speciesOut.write(assignments[1][j] + "\n")
		for i in range(2, largestSpecies + 1):
			speciesOut.write("\nSpecies " + str(i) + ":\n")
			for j in range(0, len(assignments[i])):
				speciesOut.write(assignments[i][j] + "\n")

		speciesOut.close()
	except IOError:
		print "File not found: " + input_species_file

set_names = ["Ne1e+05", "Ne1e+06", "Ne5e+05", "Ne10000"]

#rewrite_species_result("gmyc_results_SimulB_C/set_Ne1e+05/gmyc_results_set_Ne1e+05.1.txt", "SimulB_C_gmyc_minbr_0/set_Ne1e+05/gmyc_results_set_Ne1e+05.1.txt")

for set_name in set_names:
	for i in range(1,101):
		input_species_file = "gmyc_results_SimulB_C/set_" + set_name + "/gmyc_results_set_" + set_name + "." + str(i) + ".txt"
		output_species_file = "SimulB_C_gmyc_minbr_0/set_" + set_name + "/gmyc_results_set_" + set_name + "." + str(i) + ".txt"
		rewrite_species_result(input_species_file, output_species_file)



#! /usr/bin/env python

import commands
import time

def evaluate(treeFile, rooted):
	cmd_multi = './delimit --ptp_multi --tree_file ' + treeFile + ' --output_file foo'
	cmd_single = './delimit --ptp_single --tree_file ' + treeFile + ' --output_file foo'
	cmd_ptp_rooted = './PTP/PTP.py -t ' + treeFile + ' -p -minbr 0 -o output -pvalue 1'
	cmd_ptp_unrooted = './PTP/PTP.py -t ' + treeFile + ' -p -minbr 0 -o output -pvalue 1 -r'

	if (rooted):
		programs = [cmd_multi, cmd_single, cmd_ptp_rooted]
		cmd_ptp = cmd_ptp_rooted
	else:
		programs = [cmd_multi, cmd_single, cmd_ptp_unrooted]
		cmd_ptp = cmd_ptp_unrooted

	scores = {}
	times = {}

	print "Testing " + treeFile + "..."

	# cmd_ptp:
	ts = time.time()
	( stat, output ) = commands.getstatusoutput(cmd_ptp)
	te = time.time()
	times['ptp'] = te-ts
	#print output
	left = output.find("MAX logl: ")
	right = output[left+10:].find("\n")
	score = output[left+10:right+left+10]
	scores['ptp'] = score

	# cmd_multi:
	ts = time.time()
	( stat, output ) = commands.getstatusoutput(cmd_multi)
	te = time.time()
	times['multi'] = te-ts
	#print output
	left = output.find("Best score found single: ")
	right = output[left+25:].find("\n")
	score = output[left+25:right+left+25]
	scores['multi'] = score

	# cmd_single:
	ts = time.time()
	( stat, output ) = commands.getstatusoutput(cmd_single)
	te = time.time()
	times['single'] = te-ts
	#print output
	left = output.find("Best score found single: ")
	right = output[left+25:].find("\n")
	score = output[left+25:right+left+25]
	scores['single'] = score
	
	print 'scores: '
	print scores
	print 'times: '
	print times
	print '\n'

	return scores

def compare_rooted():
	with open('tree_names_rooted') as f_rooted:
		content = f_rooted.read().splitlines()
	#gnuplotOut = open('workfile', 'w')
	for i in range (0, len(content)):
		scores = evaluate('trees/' + content[i], True)
		#gnuplotOut.write(str(i) + ' ' + scores['ptp'] + ' ' + scores['multi'] + ' ' + scores['single'] + '\n')
		#print evaluate('trees/' + name)
	#gnuplotOut.close()
	#commands.getstatusoutput('gnuplot plotscript')
	f_rooted.close()

def compare_unrooted():
	with open('tree_names_unrooted') as f_unrooted:
		content = f_unrooted.read().splitlines()
	#gnuplotOut = open('workfile', 'w')
	for i in range (0, len(content)):
		scores = evaluate('trees/' + content[i], False)
		#gnuplotOut.write(str(i) + ' ' + scores['ptp'] + ' ' + scores['multi'] + ' ' + scores['single'] + '\n')
		#print evaluate('trees/' + name)
	#gnuplotOut.close()
	#commands.getstatusoutput('gnuplot plotscript')
	f_unrooted.close()

compare_unrooted()
compare_rooted()



#! /usr/bin/env python
import os

def create_subsets(alignmentFile, num_of_species, sum_of_species, num_basepairs, output_taxa_file, output_alignment_file, num_alignments):
	try:
		with open(alignmentFile) as f:
			content = f.read().splitlines()
		f.close()
		speciesList = []

		for i in range(0,31):
			emptyList = []
			speciesList.append(emptyList)

		alignments = {}
		for i in range(1, len(content)): # ignore first line
			contentSplitted = content[i].split();
			taxonName = contentSplitted[0]
			alignments[taxonName] = contentSplitted[1][0:num_basepairs]
			species = taxonName.split('.')[0]
			speciesList[int(species)].append(taxonName)

		speciesListSorted = sorted(speciesList, key = len)

		currentIdx = 0

		selectedTaxa = []

		found = 0
		for i in range(30,-1,-1):
			if currentIdx < len(num_of_species):
				if len(speciesListSorted[i]) >= sum_of_species[currentIdx]:
					found = found + 1
					for j in range(1, sum_of_species[currentIdx]):
						selectedTaxa.append(speciesListSorted[i][j])
				else:
					print "We had an error :("
				if found == num_of_species[currentIdx]:
					currentIdx = currentIdx + 1
					found = 0

		# write the solutions into the files
		if not os.path.exists(os.path.dirname(output_taxa_file)):
    			os.makedirs(os.path.dirname(output_taxa_file))
		taxaOut = open(output_taxa_file, 'w')
		for taxon in selectedTaxa:
			taxaOut.write(taxon + "\n")
		taxaOut.close()

		if not os.path.exists(os.path.dirname(output_alignment_file)):
    			os.makedirs(os.path.dirname(output_alignment_file))
		alignmentOut = open(output_alignment_file, 'w')
		alignmentOut.write(str(num_alignments) + " " + str(num_basepairs) + "\n")
		for taxon in selectedTaxa:
			alignmentOut.write(taxon + " "+ alignments[taxon] + "\n")
		alignmentOut.close()

		return (currentIdx >= len(num_of_species))
    	except IOError:
		print "File not found: " + alignmentFile


set_names = ["set_1", "set_5", "set_10", "set_20", "set_40", "set_80", "set_160"]
num_of_species = [3, 6, 9, 12]
size_of_species = [35, 25, 10, 2]
uniform_num = [30]
uniform_size = [12]
base_pairs = [100, 250, 500, 1000]
uniform_num_alignments = 360
nonuniform_num_alignments = 369

for set_name in set_names:
	for i in range(1,101):
		for bp in base_pairs:
			output_nonuniform_taxa_file = "nonuniform/taxa/"+str(bp)+"/taxa.simulated_" + set_name + "_" + str(i)
			output_nonuniform_alignment_file = "nonuniform/alignments/"+str(bp)+"/simulated_tree_" + set_name + "_" + str(i)
			output_uniform_taxa_file = "uniform/taxa/"+str(bp)+"/taxa.simulated_" + set_name + "_" + str(i)
			output_uniform_alignment_file = "uniform/alignments/"+str(bp)+"/simulated_tree_" + set_name + "_" + str(i)

			alignmentFile = "reduced_alignments/" + set_name + "/simulated_" + set_name + "_" + str(i) + ".phy.reduced"
			if create_subsets(alignmentFile, num_of_species, size_of_species, bp, output_nonuniform_taxa_file, output_nonuniform_alignment_file, nonuniform_num_alignments) == False:
				print "Found a file that does not fit our requirement :-("
			if create_subsets(alignmentFile, uniform_num, uniform_size, bp, output_uniform_taxa_file, output_uniform_alignment_file, uniform_num_alignments) == False:
				print "Found a file that does not fit our requirement :-("



#! /usr/bin/env python
import os

def rewrite_species_result(input_species_file, output_species_file):
	try:
		with open(input_species_file) as f:
			content = f.read().splitlines()
		f.close()

		taxaListString = content[0].split(':')[1]
		taxaList = taxaListString.split(',')
		speciesList = content[1].split(',')

		if not os.path.exists(os.path.dirname(output_species_file)):
    			os.makedirs(os.path.dirname(output_species_file))
		speciesOut = open(output_species_file, 'w')

		oldSpeciesIdx = speciesList[0]
		speciesOut.write("Species " + oldSpeciesIdx + ":\n")
		speciesOut.write(taxaList[0] + "\n")
		for i in range(1,len(speciesList)):
			if (speciesList[i] == oldSpeciesIdx):
				speciesOut.write(taxaList[i] + "\n")
			else:
				oldSpeciesIdx = speciesList[i]
				speciesOut.write("\nSpecies " + oldSpeciesIdx + ":\n")
				speciesOut.write(taxaList[i] + "\n")

		speciesOut.close()
	except IOError:
		print "File not found: " + input_species_file

set_names = ["Ne10000", "Ne100000", "Ne500000", "Ne1000000"]

for set_name in set_names:
	for i in range(1,101):
		if set_name == "Ne10000":
			input_species_file = "similar_to_GMYC/15-08-2015.16-40/set_BIRTH0.27_" + set_name + "/PTP_result_BIRTH0.27_" + set_name + "_" + str(i) + ".PTPPartitions.txt"
		elif set_name == "Ne500000":
			input_species_file = "similar_to_GMYC/15-08-2015.16-40/set_BIRTH0.27_" + set_name + "/PTP_BIRTH0.27_" + set_name + "_" + str(i) + ".PTPPartitions.txt"
		elif set_name == "Ne100000":
			input_species_file = "similar_to_GMYC/15-08-2015.16-40/set_BIRTH0.27_" + set_name + "/PTP_BIRTH0.27_" + set_name + "_" + str(i) + ".PTPPartitions.txt"
		else:
			input_species_file = "similar_to_GMYC/15-08-2015.16-40/set_BIRTH0.27_" + set_name + "/PTP_result." + str(i) + ".PTPPartitions.txt"
		output_species_file = "similar_to_GMYC_PTP_minbr_default/set_" + set_name + "/PTP_results_set_" + set_name + "." + str(i) + ".txt"
		rewrite_species_result(input_species_file, output_species_file)



#! /usr/bin/env python
import os
import commands

def run_delimit_on_data(input_tree_file, output_delimit_single_minbr_0_file, output_delimit_multi_minbr_0_file, output_delimit_single_minbr_default_file, output_delimit_multi_minbr_default_file):
	try:
		open(input_tree_file)
		
		if not os.path.exists(os.path.dirname(output_delimit_single_minbr_0_file)):
	    			os.makedirs(os.path.dirname(output_delimit_single_minbr_0_file))
		if not os.path.exists(os.path.dirname(output_delimit_multi_minbr_0_file)):
	    			os.makedirs(os.path.dirname(output_delimit_multi_minbr_0_file))
		if not os.path.exists(os.path.dirname(output_delimit_single_minbr_default_file)):
	    			os.makedirs(os.path.dirname(output_delimit_single_minbr_default_file))
		if not os.path.exists(os.path.dirname(output_delimit_multi_minbr_default_file)):
	    			os.makedirs(os.path.dirname(output_delimit_multi_minbr_default_file))

		delimit_single_minbr_0_call = "./delimit --ml_single --min_br 0 --tree_file " + input_tree_file + " --output_file foo"
		delimit_multi_minbr_0_call = "./delimit --ml_multi --min_br 0 --tree_file " + input_tree_file + " --output_file foo"
		delimit_single_minbr_default_call = "./delimit --ml_single --tree_file " + input_tree_file + " --output_file foo"
		delimit_multi_minbr_default_call = "./delimit --ml_multi --tree_file " + input_tree_file + " --output_file foo"

		(stat_single_minbr_0, output_single_minbr_0) = commands.getstatusoutput(delimit_single_minbr_0_call)
		(stat_multi_minbr_0, output_multi_minbr_0) = commands.getstatusoutput(delimit_multi_minbr_0_call)
		(stat_single_minbr_default, output_single_minbr_default) = commands.getstatusoutput(delimit_single_minbr_default_call)
		(stat_multi_minbr_default, output_multi_minbr_default) = commands.getstatusoutput(delimit_multi_minbr_default_call)

		delimit_single_minbr_0_out = open(output_delimit_single_minbr_0_file, 'w')
		delimit_multi_minbr_0_out = open(output_delimit_multi_minbr_0_file, 'w')
		delimit_single_minbr_default_out = open(output_delimit_single_minbr_default_file, 'w')
		delimit_multi_minbr_default_out = open(output_delimit_multi_minbr_default_file, 'w')

		delimit_single_minbr_0_out.write(output_single_minbr_0)
		delimit_multi_minbr_0_out.write(output_multi_minbr_0)
		delimit_single_minbr_default_out.write(output_single_minbr_default)
		delimit_multi_minbr_default_out.write(output_multi_minbr_default)

		delimit_single_minbr_0_out.close()
		delimit_multi_minbr_0_out.close()
		delimit_single_minbr_default_out.close()
		delimit_multi_minbr_default_out.close()
	except IOError:
		print "File not found: " + input_tree_file

set_names = ["Ne1e+05", "Ne1e+06", "Ne5e+05", "Ne10000"]

for set_name in set_names:
	for i in range(1,101):
		input_tree_file = "SimulB_C_trees/set_" + set_name + "/SimulB_C_tree_set_" + set_name + "." + str(i) + ".txt"
		output_delimit_single_minbr_0_file = "SimulB_C_delimit_single_minbr_0/set_" + set_name + "/delimit_results_set_" + set_name + "." + str(i) + ".txt"
		output_delimit_multi_minbr_0_file = "SimulB_C_delimit_multi_minbr_0/set_" + set_name + "/delimit_results_set_" + set_name + "." + str(i) + ".txt"
		output_delimit_single_minbr_default_file = "SimulB_C_delimit_single_minbr_default/set_" + set_name + "/delimit_results_set_" + set_name + "." + str(i) + ".txt"
		output_delimit_multi_minbr_default_file = "SimulB_C_delimit_multi_minbr_default/set_" + set_name + "/delimit_results_set_" + set_name + "." + str(i) + ".txt"
		run_delimit_on_data(input_tree_file, output_delimit_single_minbr_0_file, output_delimit_multi_minbr_0_file, output_delimit_single_minbr_default_file, output_delimit_multi_minbr_default_file)



#! /usr/bin/env python
import os
import commands

set_names = ["Ne1e+05", "Ne1e+06", "Ne5e+05", "Ne10000"]

for set_name in set_names:
	try:
		tree_path = "SimulB&C." + set_name + "_nospec.phy"
		tree_file = open(tree_path)
		lines = tree_file.readlines()

		for i in range(1,101): # only the first 100 trees
			tree_destination = "SimulB_C_trees/set_" + set_name + "/SimulB_C_tree_set_" + set_name + "." + str(i) + ".txt"
			if not os.path.exists(os.path.dirname(tree_destination)):
		    		os.makedirs(os.path.dirname(tree_destination))
			tree_destination_file = open(tree_destination, 'w')
			tree_destination_file.write(lines[i - 1])
		
		tree_file.close()
	except IOError:
		print "File not found: " + tree_path



#! /usr/bin/env python
import os
import commands

def extract_tree_score(input_text):
	lines = input_text.split('\n')
	for line in lines:
		if line.startswith("Tree penalty score:"):
			return int(line.split(': ')[1])
			break

def extract_nmi_score(input_text):
	lines = input_text.split('\n')
	for line in lines:
		if line.startswith("NMI score:"):
			return float(line.split(': ')[1])
			break

def extract_num_species(input_text):
	lines = input_text.split('\n')
	for line in lines:
		if line.startswith("Number of species in input file:"):
			return int(line.split(': ')[1])
			if (int(line.split(': ')[1]) == 1):
				print "Baaaaad data"
			break

def extract_num_real_species(input_text):
	lines = input_text.split('\n')
	for line in lines:
		if line.startswith("Number of real species:"):
			return int(line.split(': ')[1])
			break

def extract_score_real_single(input_text):
	lines = input_text.split('\n')
	for line in lines:
		if line.startswith("Score real single:"):
			return float(line.split(': ')[1])
			break

def extract_score_real_multi(input_text):
	lines = input_text.split('\n')
	for line in lines:
		if line.startswith("Score real multi:"):
			return float(line.split(': ')[1])
			break

def extract_score_input_single(input_text):
	lines = input_text.split('\n')
	for line in lines:
		if line.startswith("Score input single:"):
			return float(line.split(': ')[1])
			break

def extract_score_input_multi(input_text):
	lines = input_text.split('\n')
	for line in lines:
		if line.startswith("Score input multi:"):
			return float(line.split(': ')[1])
			break

def grab_scorings(input_tree_file, output_delimit_single_minbr_0, output_delimit_multi_minbr_0, output_delimit_single_minbr_default, output_delimit_multi_minbr_default, output_PTP_minbr_default, output_gmyc_minbr_0):
	try:
		open(input_tree_file)
		programNames = ['delimit_single_minbr_0', 'delimit_multi_minbr_0', 'delimit_single_minbr_default', 'delimit_multi_minbr_default', 'PTP_minbr_default', 'gmyc_minbr_0']
		tree_scores = {}
		nmi_scores = {}
		num_species = {}
		single_scores = {}
		multi_scores = {}
		num_real_species = 0
		score_real_single_minbr_0 = 0
		score_real_multi_minbr_0 = 0
		score_real_single_minbr_default = 0
		score_real_multi_minbr_default = 0

		tree_scores['delimit_single_minbr_0'] = extract_tree_score(output_delimit_single_minbr_0)
		tree_scores['delimit_multi_minbr_0'] = extract_tree_score(output_delimit_multi_minbr_0)
		tree_scores['delimit_single_minbr_default'] = extract_tree_score(output_delimit_single_minbr_default)
		tree_scores['delimit_multi_minbr_default'] = extract_tree_score(output_delimit_multi_minbr_default)
		tree_scores['PTP_minbr_default'] = extract_tree_score(output_PTP_minbr_default)
		tree_scores['gmyc_minbr_0'] = extract_tree_score(output_gmyc_minbr_0)

		nmi_scores['delimit_single_minbr_0'] = extract_nmi_score(output_delimit_single_minbr_0)
		nmi_scores['delimit_multi_minbr_0'] = extract_nmi_score(output_delimit_multi_minbr_0)
		nmi_scores['delimit_single_minbr_default'] = extract_nmi_score(output_delimit_single_minbr_default)
		nmi_scores['delimit_multi_minbr_default'] = extract_nmi_score(output_delimit_multi_minbr_default)
		nmi_scores['PTP_minbr_default'] = extract_nmi_score(output_PTP_minbr_default)
		nmi_scores['gmyc_minbr_0'] = extract_nmi_score(output_gmyc_minbr_0)

		num_species['delimit_single_minbr_0'] = extract_num_species(output_delimit_single_minbr_0)
		num_species['delimit_multi_minbr_0'] = extract_num_species(output_delimit_multi_minbr_0)
		num_species['delimit_single_minbr_default'] = extract_num_species(output_delimit_single_minbr_default)
		num_species['delimit_multi_minbr_default'] = extract_num_species(output_delimit_multi_minbr_default)
		num_species['PTP_minbr_default'] = extract_num_species(output_PTP_minbr_default)
		num_species['gmyc_minbr_0'] = extract_num_species(output_gmyc_minbr_0)

		single_scores['delimit_single_minbr_0'] = extract_score_input_single(output_delimit_single_minbr_0)
		single_scores['delimit_multi_minbr_0'] = extract_score_input_single(output_delimit_multi_minbr_0)
		single_scores['delimit_single_minbr_default'] = extract_score_input_single(output_delimit_single_minbr_default)
		single_scores['delimit_multi_minbr_default'] = extract_score_input_single(output_delimit_multi_minbr_default)
		single_scores['PTP_minbr_default'] = extract_score_input_single(output_PTP_minbr_default)
		single_scores['gmyc_minbr_0'] = extract_score_input_single(output_gmyc_minbr_0)

		multi_scores['delimit_single_minbr_0'] = extract_score_input_multi(output_delimit_single_minbr_0)
		multi_scores['delimit_multi_minbr_0'] = extract_score_input_multi(output_delimit_multi_minbr_0)
		multi_scores['delimit_single_minbr_default'] = extract_score_input_multi(output_delimit_single_minbr_default)
		multi_scores['delimit_multi_minbr_default'] = extract_score_input_multi(output_delimit_multi_minbr_default)
		multi_scores['PTP_minbr_default'] = extract_score_input_multi(output_PTP_minbr_default)
		multi_scores['gmyc_minbr_0'] = extract_score_input_multi(output_gmyc_minbr_0)

		score_real_single_minbr_0 = extract_score_real_single(output_delimit_single_minbr_0)
		score_real_multi_minbr_0 = extract_score_real_multi(output_delimit_single_minbr_0)
		score_real_single_minbr_default = extract_score_real_single(output_delimit_single_minbr_default)
		score_real_multi_minbr_default = extract_score_real_multi(output_delimit_single_minbr_default)
		num_real_species = extract_num_real_species(output_delimit_single_minbr_0)

		return (tree_scores, nmi_scores, num_species, single_scores, multi_scores, score_real_single_minbr_0, score_real_multi_minbr_0, score_real_single_minbr_default, score_real_multi_minbr_default, num_real_species)
	except IOError:
		print "File not found: " + input_tree_file

def create_scoring_results(input_tree_file, input_delimit_single_minbr_0_file, input_delimit_multi_minbr_0_file, input_delimit_single_minbr_default_file, input_delimit_multi_minbr_default_file, input_PTP_minbr_default_file, input_gmyc_minbr_0_file, output_delimit_single_minbr_0_file, output_delimit_multi_minbr_0_file, output_delimit_single_minbr_default_file, output_delimit_multi_minbr_default_file, output_PTP_minbr_default_file, output_gmyc_minbr_0_file):
	try:
		open(input_tree_file)
		if not os.path.exists(os.path.dirname(output_delimit_single_minbr_0_file)):
	    			os.makedirs(os.path.dirname(output_delimit_single_minbr_0_file))
		if not os.path.exists(os.path.dirname(output_delimit_multi_minbr_0_file)):
	    			os.makedirs(os.path.dirname(output_delimit_multi_minbr_0_file))
		if not os.path.exists(os.path.dirname(output_delimit_single_minbr_default_file)):
	    			os.makedirs(os.path.dirname(output_delimit_single_minbr_default_file))
		if not os.path.exists(os.path.dirname(output_delimit_multi_minbr_default_file)):
	    			os.makedirs(os.path.dirname(output_delimit_multi_minbr_default_file))
		if not os.path.exists(os.path.dirname(output_PTP_minbr_default_file)):
	    			os.makedirs(os.path.dirname(output_PTP_minbr_default_file))
		if not os.path.exists(os.path.dirname(output_gmyc_minbr_0_file)):
	    			os.makedirs(os.path.dirname(output_gmyc_minbr_0_file))

		call_delimit_single_minbr_0 = "./delimit --score " + input_delimit_single_minbr_0_file + " --min_br 0 --tree_file " + input_tree_file + " --output_file foo"
		call_delimit_multi_minbr_0 = "./delimit --score " + input_delimit_multi_minbr_0_file + " --min_br 0 --tree_file " + input_tree_file + " --output_file foo"
		call_delimit_single_minbr_default = "./delimit --score " + input_delimit_single_minbr_default_file + " --tree_file " + input_tree_file + " --output_file foo"
		call_delimit_multi_minbr_default = "./delimit --score " + input_delimit_multi_minbr_default_file + " --tree_file " + input_tree_file + " --output_file foo"
		call_PTP_minbr_default = "./delimit --score " + input_PTP_minbr_default_file + " --min_br 0 --tree_file " + input_tree_file + " --output_file foo"
		call_gmyc_minbr_0 = "./delimit --score " + input_gmyc_minbr_0_file + " --min_br 0 --tree_file " + input_tree_file + " --output_file foo"

		(stat_delimit_single_minbr_0, output_delimit_single_minbr_0) = commands.getstatusoutput(call_delimit_single_minbr_0)
		(stat_delimit_multi_minbr_0, output_delimit_multi_minbr_0) = commands.getstatusoutput(call_delimit_multi_minbr_0)
		(stat_delimit_single_minbr_default, output_delimit_single_minbr_default) = commands.getstatusoutput(call_delimit_single_minbr_default)
		(stat_delimit_multi_minbr_default, output_delimit_multi_minbr_default) = commands.getstatusoutput(call_delimit_multi_minbr_default)
		(stat_PTP_minbr_default, output_PTP_minbr_default) = commands.getstatusoutput(call_PTP_minbr_default)
		(stat_gmyc_minbr_0, output_gmyc_minbr_0) = commands.getstatusoutput(call_gmyc_minbr_0)

		delimit_single_minbr_0_out = open(output_delimit_single_minbr_0_file, 'w')
		delimit_multi_minbr_0_out = open(output_delimit_multi_minbr_0_file, 'w')
		delimit_single_minbr_default_out = open(output_delimit_single_minbr_default_file, 'w')
		delimit_multi_minbr_default_out = open(output_delimit_multi_minbr_default_file, 'w')
		PTP_minbr_default_out = open(output_PTP_minbr_default_file, 'w')
		gmyc_minbr_0_out = open(output_gmyc_minbr_0_file, 'w')

		delimit_single_minbr_0_out.write(output_delimit_single_minbr_0)
		delimit_multi_minbr_0_out.write(output_delimit_multi_minbr_0)
		delimit_single_minbr_default_out.write(output_delimit_single_minbr_default)
		delimit_multi_minbr_default_out.write(output_delimit_multi_minbr_default)
		PTP_minbr_default_out.write(output_PTP_minbr_default)
		gmyc_minbr_0_out.write(output_gmyc_minbr_0)

		delimit_single_minbr_0_out.close()
		delimit_multi_minbr_0_out.close()
		delimit_single_minbr_default_out.close()
		delimit_multi_minbr_default_out.close()
		PTP_minbr_default_out.close()
		gmyc_minbr_0_out.close()

		return grab_scorings(input_tree_file, output_delimit_single_minbr_0, output_delimit_multi_minbr_0, output_delimit_single_minbr_default, output_delimit_multi_minbr_default, output_PTP_minbr_default, output_gmyc_minbr_0)
	except IOError:
		print "File not found: " + input_tree_file

set_names = ["Ne10000", "Ne100000", "Ne500000", "Ne1000000"]
names = ['delimit_single_minbr_0', 'delimit_multi_minbr_0', 'delimit_single_minbr_default', 'delimit_multi_minbr_default', 'PTP_minbr_default', 'gmyc_minbr_0']

gnuplotOut_tree_scores = open('workfile_tree_scores', 'w')
gnuplotOut_nmi_scores = open('workfile_nmi_scores', 'w')
gnuplotOut_single_scores = open('workfile_single_scores', 'w')
gnuplotOut_multi_scores = open('workfile_multi_scores', 'w')
gnuplotOut_num_species = open('workfile_num_species', 'w')

for set_name in set_names:
	gnuplotOut_tree_scores_current_set = open('workfile_tree_scores_' + set_name, 'w')
	gnuplotOut_nmi_scores_current_set = open('workfile_nmi_scores_' + set_name, 'w')
	gnuplotOut_single_scores_current_set = open('workfile_single_scores_' + set_name, 'w')
	gnuplotOut_multi_scores_current_set = open('workfile_multi_scores_' + set_name, 'w')
	gnuplotOut_num_species_current_set = open('workfile_num_species_' + set_name, 'w')
	gnuplotOut_delta_species_current_set = open('workfile_delta_species_' + set_name, 'w')

	num_valid_indices = 0
	average_tree_scores = {}	
	average_nmi_scores = {}
	average_num_species = {}
	average_single_scores = {}
	average_multi_scores = {}
	average_real_num_species = 0
	average_real_score_single_minbr_0 = 0
	average_real_score_multi_minbr_0 = 0
	average_real_score_single_minbr_default = 0
	average_real_score_multi_minbr_default = 0

	for name in names:
		average_tree_scores[name] = 0
		average_nmi_scores[name] = 0
		average_num_species[name] = 0
		average_single_scores[name] = 0
		average_multi_scores[name] = 0
		num_bad_guys = 0

	for i in range(1,101):
		input_tree_file = "similar_to_GMYC/15-08-2015.16-40/set_BIRTH0.27_" + set_name + "/rooted.RAxML_result.inferred.simulated_set_BIRTH0.27_" + set_name + "_" + str(i) + ".phy"

		try:
			open(input_tree_file)

			input_delimit_single_minbr_0_file = "similar_to_GMYC_delimit_single_minbr_0/set_" + set_name + "/delimit_results_set_" + set_name + "." + str(i) + ".txt"
			input_delimit_multi_minbr_0_file = "similar_to_GMYC_delimit_multi_minbr_0/set_" + set_name + "/delimit_results_set_" + set_name + "." + str(i) + ".txt"
			input_delimit_single_minbr_default_file = "similar_to_GMYC_delimit_single_minbr_default/set_" + set_name + "/delimit_results_set_" + set_name + "." + str(i) + ".txt"
			input_delimit_multi_minbr_default_file = "similar_to_GMYC_delimit_multi_minbr_default/set_" + set_name + "/delimit_results_set_" + set_name + "." + str(i) + ".txt"
			input_PTP_minbr_default_file = "similar_to_GMYC_PTP_minbr_default/set_" + set_name + "/PTP_results_set_" + set_name + "." + str(i) + ".txt"
			input_gmyc_minbr_0_file = "similar_to_GMYC_gmyc_minbr_0/set_" + set_name + "/gmyc_results_set_" + set_name + "." + str(i) + ".txt"
		
			score_path = "similar_to_GMYC_scoring_results/"		
			output_delimit_single_minbr_0_file = score_path + "delimit_single_minbr_0/set_" + set_name + "/delimit_score_set_" + set_name + "." + str(i) + ".txt"
			output_delimit_multi_minbr_0_file = score_path + "delimit_multi_minbr_0/set_" + set_name + "/delimit_score_set_" + set_name + "." + str(i) + ".txt"
			output_delimit_single_minbr_default_file = score_path + "delimit_single_minbr_default/set_" + set_name + "/delimit_score_set_" + set_name + "." + str(i) + ".txt"
			output_delimit_multi_minbr_default_file = score_path + "delimit_multi_minbr_default/set_" + set_name + "/delimit_score_set_" + set_name + "." + str(i) + ".txt"
			output_PTP_minbr_default_file = score_path + "PTP_minbr_default/set_" + set_name + "/PTP_score_set_" + set_name + "." + str(i) + ".txt"
			output_gmyc_minbr_0_file = score_path + "gmyc_minbr_0/set_" + set_name + "/PTP_score_set_" + set_name + "." + str(i) + ".txt"

			(tree_scores, nmi_scores, num_species, single_scores, multi_scores, score_real_single_minbr_0, score_real_multi_minbr_0, score_real_single_minbr_default, score_real_multi_minbr_default, num_real_species) = create_scoring_results(input_tree_file, input_delimit_single_minbr_0_file, input_delimit_multi_minbr_0_file, input_delimit_single_minbr_default_file, input_delimit_multi_minbr_default_file, input_PTP_minbr_default_file, input_gmyc_minbr_0_file, output_delimit_single_minbr_0_file, output_delimit_multi_minbr_0_file, output_delimit_single_minbr_default_file, output_delimit_multi_minbr_default_file, output_PTP_minbr_default_file, output_gmyc_minbr_0_file)

			gnuplotOut_tree_scores_current_set.write(str(i) + ' ' + str(tree_scores['delimit_single_minbr_0']) + ' ' + str(tree_scores['delimit_multi_minbr_0']) + ' ' + str(tree_scores['delimit_single_minbr_default']) + ' ' + str(tree_scores['delimit_multi_minbr_default']) + ' ' + str(tree_scores['PTP_minbr_default']) + ' ' + str(tree_scores['gmyc_minbr_0']) + '\n')

			gnuplotOut_nmi_scores_current_set.write(str(i) + ' ' + str(nmi_scores['delimit_single_minbr_0']) + ' ' + str(nmi_scores['delimit_multi_minbr_0']) + ' ' + str(nmi_scores['delimit_single_minbr_default']) + ' ' + str(nmi_scores['delimit_multi_minbr_default']) + ' ' + str(nmi_scores['PTP_minbr_default']) + ' ' + str(nmi_scores['gmyc_minbr_0']) + '\n')

			gnuplotOut_single_scores_current_set.write(str(i) + ' ' + str(single_scores['delimit_single_minbr_0']) + ' ' + str(single_scores['delimit_multi_minbr_0']) + ' ' + str(single_scores['delimit_single_minbr_default']) + ' ' + str(single_scores['delimit_multi_minbr_default']) + ' ' + str(single_scores['PTP_minbr_default']) + ' ' + str(score_real_single_minbr_0) + ' ' + str(single_scores['gmyc_minbr_0']) + ' ' + str(score_real_single_minbr_default) + '\n')

			gnuplotOut_multi_scores_current_set.write(str(i) + ' ' + str(multi_scores['delimit_single_minbr_0']) + ' ' + str(multi_scores['delimit_multi_minbr_0']) + ' ' + str(multi_scores['delimit_single_minbr_default']) + ' ' + str(multi_scores['delimit_multi_minbr_default']) + ' ' + str(multi_scores['PTP_minbr_default']) + ' ' + str(score_real_multi_minbr_0) + ' ' + ' ' + str(multi_scores['gmyc_minbr_0']) + str(score_real_multi_minbr_default) + '\n')

			gnuplotOut_num_species_current_set.write(str(i) + ' ' + str(num_species['delimit_single_minbr_0']) + ' ' + str(num_species['delimit_multi_minbr_0']) + ' ' + str(num_species['delimit_single_minbr_default']) + ' ' + str(num_species['delimit_multi_minbr_default']) + ' ' + str(num_species['PTP_minbr_default']) + ' ' + str(num_species['gmyc_minbr_0']) + ' ' + str(num_real_species) + '\n')

			gnuplotOut_delta_species_current_set.write(str(i) + ' ' + str(num_species['delimit_single_minbr_0'] - num_real_species) + ' ' + str(num_species['delimit_multi_minbr_0'] - num_real_species) + ' ' + str(num_species['delimit_single_minbr_default'] - num_real_species) + ' ' + str(num_species['delimit_multi_minbr_default'] - num_real_species) + ' ' + str(num_species['PTP_minbr_default'] - num_real_species) + ' ' + str(num_species['gmyc_minbr_0'] - num_real_species) + ' ' + str(num_real_species - num_real_species) + '\n')


			try:
				for name in names:
					average_tree_scores[name] = average_tree_scores[name] + tree_scores[name]
					average_nmi_scores[name] = average_nmi_scores[name] + nmi_scores[name]
					average_num_species[name] = average_num_species[name] + num_species[name]
					average_single_scores[name] = average_single_scores[name] + single_scores[name]
					average_multi_scores[name] = average_multi_scores[name] + multi_scores[name]
				average_real_num_species = average_real_num_species + num_real_species
				average_real_score_single_minbr_0 = average_real_score_single_minbr_0 + score_real_single_minbr_0
				average_real_score_multi_minbr_0 = average_real_score_multi_minbr_0 + score_real_multi_minbr_0
				average_real_score_single_minbr_default = average_real_score_single_minbr_default + score_real_single_minbr_default
				average_real_score_multi_minbr_default = average_real_score_multi_minbr_default + score_real_multi_minbr_default
			except:
				print "File is bad: " + input_tree_file
				num_valid_indices = num_valid_indices - 1
				num_bad_guys = num_bad_guys + 1

			num_valid_indices = num_valid_indices + 1
		except IOError:
			#1
			print "File not found: " + input_tree_file

	#print "Set " + set_name + ": Num bad guys " + str(num_bad_guys)
	#print "Set " + set_name + ": Num good guys " + str(num_valid_indices)

	if (num_valid_indices > 0):
		for name in names:
			average_tree_scores[name] = float(average_tree_scores[name]) / float(num_valid_indices)
			average_nmi_scores[name] = float(average_nmi_scores[name]) / float(num_valid_indices)
			average_num_species[name] = float(average_num_species[name]) / float(num_valid_indices)
			average_single_scores[name] = float(average_single_scores[name]) / float(num_valid_indices)
			average_multi_scores[name] = float(average_multi_scores[name]) / float(num_valid_indices)
		
			#print "Set " + set_name + ": Average tree score " + name
			#print average_tree_scores[name]
			#print "Set " + set_name + ": Average NMI score " + name
			#print average_nmi_scores[name]
			#print "Set " + set_name + ": Average num species " + name
			#print average_num_species[name]
			#print "Set " + set_name + ": Average input score single " + name
			#print average_single_scores[name]
			#print "Set " + set_name + ": Average input score multi " + name
			#print average_multi_scores[name]
		average_real_num_species = float(average_real_num_species) / float(num_valid_indices)
		average_real_score_single_minbr_0 = float(average_real_score_single_minbr_0) / float(num_valid_indices)
		average_real_score_multi_minbr_0 = float(average_real_score_multi_minbr_0) / float(num_valid_indices)
		average_real_score_single_minbr_default = float(average_real_score_single_minbr_default) / float(num_valid_indices)
		average_real_score_multi_minbr_default = float(average_real_score_multi_minbr_default) / float(num_valid_indices)
		#print "Set " + set_name + ": Average real num species "
		#print average_real_num_species
		#print "Set " + set_name + ": Average real score single "
		#print average_real_score_single
		#print "Set " + set_name + ": Average real score multi "
		#print average_real_score_multi

		gnuplotOut_tree_scores.write(set_name[2:] + ' ' + str(average_tree_scores['delimit_single_minbr_0']) + ' ' + str(average_tree_scores['delimit_multi_minbr_0']) + ' ' + str(average_tree_scores['delimit_single_minbr_default']) + ' ' + str(average_tree_scores['delimit_multi_minbr_default']) + ' ' + str(average_tree_scores['PTP_minbr_default']) + ' ' + str(average_tree_scores['gmyc_minbr_0']) + '\n')

		gnuplotOut_nmi_scores.write(set_name[2:] + ' ' + str(average_nmi_scores['delimit_single_minbr_0']) + ' ' + str(average_nmi_scores['delimit_multi_minbr_0']) + ' ' + str(average_nmi_scores['delimit_single_minbr_default']) + ' ' + str(average_nmi_scores['delimit_multi_minbr_default']) + ' ' + str(average_nmi_scores['PTP_minbr_default']) + ' ' + str(average_nmi_scores['gmyc_minbr_0']) + '\n')

		gnuplotOut_single_scores.write(set_name[2:] + ' ' + str(average_single_scores['delimit_single_minbr_0']) + ' ' + str(average_single_scores['delimit_multi_minbr_0']) + ' ' + str(average_single_scores['delimit_single_minbr_default']) + ' ' + str(average_single_scores['delimit_multi_minbr_default']) + ' ' + str(average_single_scores['PTP_minbr_default']) + ' ' + str(average_single_scores['gmyc_minbr_0']) + ' ' + str(average_real_score_single_minbr_0) + ' ' + str(average_real_score_single_minbr_default) + '\n')

		gnuplotOut_multi_scores.write(set_name[2:] + ' ' + str(average_multi_scores['delimit_single_minbr_0']) + ' ' + str(average_multi_scores['delimit_multi_minbr_0']) + ' ' + str(average_multi_scores['delimit_single_minbr_default']) + ' ' + str(average_multi_scores['delimit_multi_minbr_default']) + ' ' + str(average_multi_scores['PTP_minbr_default']) + ' ' + str(average_multi_scores['gmyc_minbr_0']) + ' ' + str(average_real_score_multi_minbr_0) + ' ' + str(average_real_score_multi_minbr_default) + '\n')

		gnuplotOut_num_species.write(set_name[2:] + ' ' + str(average_num_species['delimit_single_minbr_0']) + ' ' + str(average_num_species['delimit_multi_minbr_0']) + ' ' + str(average_num_species['delimit_single_minbr_default']) + ' ' + str(average_num_species['delimit_multi_minbr_default']) + ' ' + str(average_num_species['PTP_minbr_default']) + ' ' + str(average_num_species['gmyc_minbr_0']) + ' ' + str(average_real_num_species) + '\n')

	gnuplotOut_tree_scores_current_set.close()
	gnuplotOut_nmi_scores_current_set.close()
	gnuplotOut_single_scores_current_set.close()
	gnuplotOut_multi_scores_current_set.close()
	gnuplotOut_num_species_current_set.close()
	gnuplotOut_delta_species_current_set.close()

gnuplotOut_tree_scores.close()
gnuplotOut_nmi_scores.close()
gnuplotOut_single_scores.close()
gnuplotOut_multi_scores.close()
gnuplotOut_num_species.close()

commands.getstatusoutput('gnuplot plotscript')
